==> packageinstaller-pkglist-libre_0.1.3.tar.xz: packageinstaller-pkglist-libre/Georgian_LO_full.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>  
Georgian_LO_full
</name>

<description>  
   <am>Georgian Language Meta-Package for LibreOffice</am>
   <ar>Georgian Language Meta-Package for LibreOffice</ar>
   <bg>Georgian Language Meta-Package for LibreOffice</bg>
   <bn>Georgian Language Meta-Package for LibreOffice</bn>
   <ca>Metapaquet d'idioma Georgià per LibreOffice</ca>
   <cs>Georgian Language Meta-Package for LibreOffice</cs>
   <da>Georgian Language Meta-Package for LibreOffice</da>
   <de>Georgisches Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα Georgian</el>
   <en>Georgian Language Meta-Package for LibreOffice</en>
   <es>Meta-Paquete de idioma georgiano para LibreOffice</es>
   <et>Georgian Language Meta-Package for LibreOffice</et>
   <eu>Georgian Language Meta-Package for LibreOffice</eu>
   <fa>Georgian Language Meta-Package for LibreOffice</fa>
   <fil_PH>Georgian Language Meta-Package for LibreOffice</fil_PH>
   <fi>Georgian Language Meta-Package for LibreOffice</fi>
   <fr>Georgian Language Meta-Package for LibreOffice</fr>
   <he_IL>Georgian Language Meta-Package for LibreOffice</he_IL>
   <hi>Georgian Language Meta-Package for LibreOffice</hi>
   <hr>Georgian Language Meta-Package for LibreOffice</hr>
   <hu>Georgian Language Meta-Package for LibreOffice</hu>
   <id>Georgian Language Meta-Package for LibreOffice</id>
   <is>Georgian Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua georgiana per LibreOffice</it>
   <ja_JP>Georgian Language Meta-Package for LibreOffice</ja_JP>
   <ja>Georgian Language Meta-Package for LibreOffice</ja>
   <kk>Georgian Language Meta-Package for LibreOffice</kk>
   <ko>Georgian Language Meta-Package for LibreOffice</ko>
   <lt>Georgian Language Meta-Package for LibreOffice</lt>
   <mk>Georgian Language Meta-Package for LibreOffice</mk>
   <mr>Georgian Language Meta-Package for LibreOffice</mr>
   <nb>Georgian Language Meta-Package for LibreOffice</nb>
   <nl>Georgian Language Meta-Package for LibreOffice</nl>
   <pl>Georgian Language Meta-Package for LibreOffice</pl>
   <pt_BR>Georgian Language Meta-Package for LibreOffice</pt_BR>
   <pt>Georgiano Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>Georgian Language Meta-Package for LibreOffice</ro>
   <ru>Georgian Language Meta-Package for LibreOffice</ru>
   <sk>Georgian Language Meta-Package for LibreOffice</sk>
   <sl>Gruzijski jezikovni meta-paket za LibreOffice</sl>
   <sq>Georgian Language Meta-Package for LibreOffice</sq>
   <sr>Georgian Language Meta-Package for LibreOffice</sr>
   <sv>Georgiskt Språk Meta-Paket för LibreOffice</sv>
   <tr>Georgian Language Meta-Package for LibreOffice</tr>
   <uk>Georgian Language Meta-Package for LibreOffice</uk>
   <vi>Georgian Language Meta-Package for LibreOffice</vi>
   <zh_CN>Georgian Language Meta-Package for LibreOffice</zh_CN>
   <zh_TW>Georgian Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-l10n-ka
libreoffice-gtk3
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-l10n-ka
libreoffice-gtk3
</uninstall_package_names>

</app>

==> packageinstaller-pkglist-libre_0.1.7.tar.xz: packageinstaller-pkglist-libre/Georgian_LO_full.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Georgian_LO_full
</name>

<description>
   <am>Georgian Language Meta-Package for LibreOffice</am>
   <ar>Georgian Language Meta-Package for LibreOffice</ar>
   <be>Georgian Language Meta-Package for LibreOffice</be>
   <bg>Georgian Language Meta-Package for LibreOffice</bg>
   <bn>Georgian Language Meta-Package for LibreOffice</bn>
   <ca>Metapaquet d'idioma Georgià per LibreOffice</ca>
   <cs>Georgian Language Meta-Package for LibreOffice</cs>
   <da>Georgian Language Meta-Package for LibreOffice</da>
   <de>Georgisches Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα Γεωργιανά</el>
   <en>Georgian Language Meta-Package for LibreOffice</en>
   <es_ES>Meta-Paquete de idioma Georgiano para LibreOffice</es_ES>
   <es>Metapaquete de idioma Georgiano para LibreOffice</es>
   <et>Georgian Language Meta-Package for LibreOffice</et>
   <eu>Georgian Language Meta-Package for LibreOffice</eu>
   <fa>Georgian Language Meta-Package for LibreOffice</fa>
   <fil_PH>Georgian Language Meta-Package for LibreOffice</fil_PH>
   <fi>Georgialainen kielipaketti LibreOffice:lle</fi>
   <fr_BE>Méta-paquet de langue géorgienne pour LibreOffice</fr_BE>
   <fr>Méta-paquet de langue géorgienne pour LibreOffice</fr>
   <gl_ES>Xeorxiano Meta-paquete de Idioma para LibreOffice</gl_ES>
   <he_IL>Georgian Language Meta-Package for LibreOffice</he_IL>
   <hi>Georgian Language Meta-Package for LibreOffice</hi>
   <hr>Georgian Language Meta-Package for LibreOffice</hr>
   <hu>Georgian Language Meta-Package for LibreOffice</hu>
   <id>Georgian Language Meta-Package for LibreOffice</id>
   <is>Georgian Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua georgiana per LibreOffice</it>
   <ja>LibreOffice用のグルジア語メタパッケージ</ja>
   <kk>Georgian Language Meta-Package for LibreOffice</kk>
   <ko>Georgian Language Meta-Package for LibreOffice</ko>
   <lt>Georgian Language Meta-Package for LibreOffice</lt>
   <mk>Georgian Language Meta-Package for LibreOffice</mk>
   <mr>Georgian Language Meta-Package for LibreOffice</mr>
   <nb_NO>Georgian Language Meta-Package for LibreOffice</nb_NO>
   <nb>Georgisk språkpakke for LibreOffice</nb>
   <nl_BE>Georgian Language Meta-Package for LibreOffice</nl_BE>
   <nl>Georgisch Taal Meta-Pakket voor LibreOffice</nl>
   <pl>Meta-pakiet języka gruzińskiego dla LibreOffice</pl>
   <pt_BR>Georgiana Pacote de Idioma para o LibreOffice</pt_BR>
   <pt>Georgiano Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>Georgian Language Meta-Package for LibreOffice</ro>
   <ru>Georgian Language Meta-Package for LibreOffice</ru>
   <sk>Georgian Language Meta-Package for LibreOffice</sk>
   <sl>Gruzijski jezikovni meta-paket za LibreOffice</sl>
   <sq>Georgian Language Meta-Package for LibreOffice</sq>
   <sr>Georgian Language Meta-Package for LibreOffice</sr>
   <sv>Georgiskt Språk Meta-Paket för LibreOffice</sv>
   <th>Meta-Package ภาษา Georgian สำหรับ LibreOffice</th>
   <tr>LibreOffice için Gürcüce Dili Üst-Paketi</tr>
   <uk>Georgian Language Meta-Package for LibreOffice</uk>
   <vi>Georgian Language Meta-Package for LibreOffice</vi>
   <zh_CN>LibreOffice 格鲁吉亚语语言包</zh_CN>
   <zh_HK>Georgian Language Meta-Package for LibreOffice</zh_HK>
   <zh_TW>Georgian Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-l10n-ka
libreoffice-gtk3
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-l10n-ka
libreoffice-gtk3
</uninstall_package_names>

</app>
